@@ -2,7 +2,7 @@
 from pwn import *
 from pwnscripts.context import context	# Keep this at top-level
 from pwnscripts.elf import *
-from pwnscripts.string_checks import *
+from pwnscripts.util import *
 from pwnscripts.libcdb_query import *
 from pwnscripts.uncommon import *
 from pwnscripts.rop import *
